package
Version:
v0.0.0-beta.18
Opens a new window with list of versions in this module.
Published: Mar 20, 2026
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func HierarchicalLouvain(g *Graph, maxLevels, maxIter int) [][]int
HierarchicalLouvain runs Louvain at multiple levels.
Returns a slice of levels, each level is a map nodeID → communityLabel.
Louvain runs the Louvain community detection algorithm.
Returns a map from node index → community ID (integer).
type CommunityReport struct {
}
CommunityReport holds LLM-generated community metadata.
Summarize generates a community report using the LLM.
type Edge struct {
Source, Target int
Weight float64
}
Edge in the graph.
Graph represents an undirected weighted graph for community detection.
NewGraph builds a graph from node IDs and weighted edges.
NodeIndex returns the index for a node ID.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.